@@ -2,7 +2,7 @@ context("test multistar_as_flat_table")
 
 test_that("multistar_as_flat_table works", {
   ft <- ms_mrs_test %>%
-    multistar_as_flat_table(name = "mrs_age")
+    multistar_as_flat_table(fact = "mrs_age")
 
   expect_equal(
     names(ft),
@@ -23,7 +23,7 @@ test_that("multistar_as_flat_table works", {
   )
   expect_equal(length(ft[[1]]), 24)
 
-  ms <- dimensional_query(ms_mrs) %>%
+  ms <- dimensional_query(ms_mrs_test) %>%
     select_dimension(name = "where",
                      attributes = c("city", "state")) %>%
     select_dimension(name = "when",
@@ -36,7 +36,6 @@ test_that("multistar_as_flat_table works", {
       name = "mrs_cause",
       measures = c("pneumonia_and_influenza_deaths", "other_deaths")
     ) %>%
-    filter_dimension(name = "where", city == "Boston") %>%
     run_query()
   ft <- ms %>%
     multistar_as_flat_table()
@@ -55,5 +54,5 @@ test_that("multistar_as_flat_table works", {
       "mrs_cause_nrow_agg"
     )
   )
-  expect_equal(length(ft[[1]]), 9)
+  expect_equal(length(ft[[1]]), 6)
 })
